.. _supported-versions:

Supported versions
==================

``django-guardian`` supports Python 2.7+/3.3+ and Django 1.5+.

Rules
-----

* We would support Python 2.7. We also support Python 3.3+.
* Support for Python 3.3 may get dropped in the future.
* We support Django 1.5+, however next big ``guardian`` release (v2.0) we would
  support Django 1.7+ (or higher, depending on the date guardian v2.0 would be
  released). This is due to many simplifications in code we could do.
